@@ -184,11 +184,13 @@ This variable has to be set before `no-littering' is loaded.")
   "The directory where packages place their persistent data files.
 This variable has to be set before `no-littering' is loaded.")
 
+;;;###autoload
 (defun no-littering-expand-etc-file-name (file)
   "Expand filename FILE relative to `no-littering-etc-directory'."
   (expand-file-name (convert-standard-filename file)
                     no-littering-etc-directory))
 
+;;;###autoload
 (defun no-littering-expand-var-file-name (file)
   "Expand filename FILE relative to `no-littering-var-directory'."
   (expand-file-name (convert-standard-filename file)
@@ -204,7 +206,7 @@ This variable has to be set before `no-littering' is loaded.")
 
 ;;; Built-in packages
 
-    (setq abbrev-file-name                 (var "abbrev.el"))
+    (setq abbrev-file-name                 (etc "abbrev.el"))
     (setq auto-insert-directory            (etc "auto-insert/"))
     (setq auto-save-list-file-prefix       (var "auto-save/sessions/"))
     (setq backup-directory-alist           (list (cons "." (var "backup/"))))
@@ -215,8 +217,16 @@ This variable has to be set before `no-littering' is loaded.")
     (setq desktop-dirname                  (var "desktop/"))
     (setq desktop-path                     (list desktop-dirname))
     (setq diary-file                       (var "diary"))
+    (setq ecomplete-database-file          (var "ecomplete-database.el"))
     (setq ede-project-placeholder-cache-file (var "ede-projects.el"))
     (setq epkg-repository                  (var "epkgs/"))
+    (eval-after-load 'erc
+      `(make-directory ,(var "erc/dcc/") t))
+    (setq erc-dcc-get-default-directory    (var "erc/dcc/"))
+    (setq erc-log-channels-directory       (var "erc/log-channels/"))
+    (eval-after-load 'eshell
+      `(make-directory ,(etc "eshell/") t))
+    (setq eshell-aliases-file              (etc "eshell/aliases"))
     (setq eshell-directory-name            (var "eshell/"))
     (setq eudc-options-file                (etc "eudc-options.el"))
     (eval-after-load 'eww
@@ -244,7 +254,7 @@ This variable has to be set before `no-littering' is loaded.")
     (setq org-id-locations-file            (var "org/id-locations.el"))
     (setq org-publish-timestamp-directory  (var "org/timestamps/"))
     (setq org-registry-file                (var "org/registry.el"))
-    (setq project-list-file                (var "project-list"))
+    (setq project-list-file                (var "project-list.el"))
     (setq quickurl-url-file                (var "quickurl-url.el"))
     (setq rcirc-log-directory              (var "rcirc-log/"))
     (setq recentf-save-file                (var "recentf-save.el"))
@@ -255,8 +265,10 @@ This variable has to be set before `no-littering' is loaded.")
     (setq srecode-map-save-file            (var "srecode-map.el"))
     (setq semanticdb-default-save-directory (var "semantic/"))
     (setq shared-game-score-directory      (var "shared-game-score/"))
+    (setq timeclock-file                   (var "timeclock"))
     (setq tramp-auto-save-directory        (var "tramp/auto-save/"))
     (setq tramp-persistency-file-name      (var "tramp/persistency.el"))
+    (setq type-break-file-name             (var "type-break.el"))
     (setq url-cache-directory              (var "url/cache/"))
     (setq url-configuration-directory      (var "url/configuration/"))
 
@@ -368,6 +380,7 @@ directories."
     (setq org-recent-headings-save-file    (var "org/recent-headings.el"))
     (setq pandoc-data-dir                  (etc "pandoc-mode/"))
     (setq pcache-directory                 (var "pcache/"))
+    (setq persist--directory-location      (var "persist/"))
     (setq persistent-scratch-save-file     (var "persistent-scratch.el"))
     (setq persp-save-dir                   (var "persp-mode/"))
     (eval-after-load 'projectile
@@ -380,11 +393,15 @@ directories."
     (setq purpose-layout-dirs              (list (etc "window-purpose/layouts/")))
     (setq pyim-dcache-directory            (var "pyim/dcache/"))
     (setq quack-dir                        (var "quack/"))
+    (setq rfc-mode-directory               (var "rfc-mode/"))
     (setq request-storage-directory        (var "request/storage/"))
     (setq rmh-elfeed-org-files             (list (var "elfeed/rmh-elfeed.org")))
     (setq runner-init-file                 (var "runner-init.el"))
     (setq save-kill-file-name              (var "save-kill.el"))
     (setq save-visited-files-location      (var "save-visited-files-location"))
+    (eval-after-load 'sly
+      `(make-directory ,(var "sly/") t))
+    (setq sly-mrepl-history-file-name      (var "sly/mrepl-history"))
     (setq smex-save-file                   (var "smex-save.el"))
     (setq speed-type-gb-dir                (var "speed-type/"))
     (eval-after-load 'sx
@@ -396,7 +413,6 @@ directories."
     (setq transient-values-file            (etc "transient/values.el"))
     (setq treemacs-persist-file            (var "treemacs/persist.org"))
     (setq treemacs-last-error-persist-file (var "treemacs/persist-last-error.org"))
-    (setq type-break-file-name             (var "type-break.el"))
     (setq undo-fu-session-directory        (var "undo-fu-session/"))
     (setq undohist-directory               (var "undohist/"))
     (setq undo-tree-history-directory-alist (list (cons "." (var "undo-tree-hist/"))))
